"""
API for spectral_integrator



"""

#-----------------------------------------------------------------------------
# Copyright (c) 2013, yt Development Team.
#
# Distributed under the terms of the Modified BSD License.
#
# The full license is in the file COPYING.txt, distributed with this software.
#-----------------------------------------------------------------------------

from .spectral_frequency_integrator import \
    EmissivityIntegrator, \
    add_xray_emissivity_field